@@ -42,15 +42,14 @@
 #include <libhildonwm/hd-wm-desktop.h>
 #include <libhildonwm/hd-keys.h>
 
-#define HN_WANT_DEBUG 0 /* Set to 1 for more verbose hn */
+#define HD_WM_DEBUG 0 /* Set to 1 for more verbose hn */
 
-#if (HN_WANT_DEBUG)
-#define HN_DBG(x, a...) \
- fprintf(stderr, __FILE__ ":%d,%s() " x "\n", __LINE__, __func__, ##a)
+#if (HD_WM_DEBUG)
+#define hd_wm_debug(x, a...) \
+ g_debug( __FILE__ ":%d,%s() " x "\n", __LINE__, __func__, ##a)
 #else
-#define HN_DBG(x, a...) do {} while (0)
+#define hd_wm_debug(x, a...) do {} while (0)
 #endif
-#define HN_MARK() HN_DBG("--mark--");
 
 /* For gathering available memory information */
 #define LOWMEM_PROC_ALLOWED              "/proc/sys/vm/lowmem_allowed_pages"
@@ -232,21 +231,15 @@ hd_wm_toggle_desktop (void);
 HDWMWindow*
 hd_wm_lookup_window_via_service (const gchar *service_name);
 
-HDWMWindow*
-hd_wm_lookup_window_via_menu_widget (GtkWidget *menu_widget);
-
 HDWMApplication*
 hd_wm_lookup_application_via_service (const gchar *service_name);
 
 HDWMApplication*
 hd_wm_lookup_application_via_exec (const gchar *exec_name);
 
-HDWMApplication*
-hd_wm_lookup_application_via_menu (GtkWidget *menu);
-
 gchar *
 hd_wm_compute_window_hibernation_key (Window xwin,
-					      HDWMApplication *app);
+				      HDWMApplication *app);
 
 void
 hd_wm_monitor_register (void);
@@ -262,7 +255,7 @@ void
 hd_wm_focus_active_window (HDWM *hdwm);
 
 void 
-hd_wm_set_all_menu_button (HDWM *hdwm, GtkWidget *widget);
+hd_wm_set_all_menu_button (HDWM *hdwm, GObject *menu_button);
 
 gboolean
 hd_wm_fullscreen_mode (void);
