@@ -342,9 +342,13 @@ hd_switcher_menu_popup_window_keypress_cb (GtkWidget      *widget,
     {
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (switcher->priv->toggle_button), FALSE);
 
-      GdkWindow *window = gtk_widget_get_parent_window (switcher->priv->toggle_button);
+      GtkWidget *window = gtk_widget_get_toplevel (switcher->priv->toggle_button);
+
+      g_object_set (window, "can-focus", TRUE, NULL);
+      
       gtk_widget_grab_focus (GTK_WIDGET (switcher->priv->toggle_button));
-      hd_wm_activate_window (HD_TN_ACTIVATE_KEY_FOCUS,window);
+      
+      hd_wm_activate_window (HD_TN_ACTIVATE_KEY_FOCUS, window->window);
     }
 
     return TRUE;
@@ -412,11 +416,23 @@ hd_switcher_menu_switcher_keypress_cb (GtkWidget      *widget,
   {
     gtk_toggle_button_set_active
       (GTK_TOGGLE_BUTTON (switcher->priv->toggle_button), TRUE);
-	  
-    g_signal_emit_by_name (switcher->priv->toggle_button, "toggled");
-  }	  
 
-  return TRUE;
+    return TRUE;
+  }	  
+  else if (event->keyval == GDK_Left ||
+           event->keyval == GDK_KP_Left)
+  {
+    gtk_widget_grab_focus (widget);
+
+    GdkWindow *w =
+      gtk_widget_get_parent_window (GTK_WIDGET (switcher->priv->toggle_button));
+
+    hd_wm_activate_window (HD_TN_ACTIVATE_KEY_FOCUS, w);
+
+    return TRUE;
+  }
+
+  return FALSE;
 }
 
 #ifdef HAVE_MCE
@@ -759,6 +775,12 @@ hd_switcher_menu_constructor (GType gtype,
     HILDON_DESKTOP_POPUP_WINDOW 
       (hildon_desktop_popup_window_new (1,GTK_ORIENTATION_HORIZONTAL,HD_POPUP_WINDOW_DIRECTION_RIGHT_BOTTOM));	     
 
+#if 0
+  g_object_set (G_OBJECT (switcher->priv->popup_window), 
+		"border-width", 4,
+		NULL);
+#endif  
+ 
   /* We don't attach the widget because if we do it, we cannot be on top of 
    * virtual keyboard. Anyway it should be transient to button
    */
@@ -769,6 +791,12 @@ hd_switcher_menu_constructor (GType gtype,
   switcher->priv->notifications_window = 
     hildon_desktop_popup_window_get_pane (switcher->priv->popup_window, 0);
 
+#if 0
+  g_object_set (G_OBJECT (switcher->priv->notifications_window), 
+		"border-width", 4,
+		NULL);
+#endif
+  
   gtk_widget_set_size_request (GTK_WIDGET (switcher->priv->popup_window),
 			       340, 100);
   
@@ -787,6 +815,7 @@ hd_switcher_menu_constructor (GType gtype,
 
   gtk_container_add (GTK_CONTAINER (switcher->priv->popup_window),
 		     GTK_WIDGET (switcher->priv->menu_applications));
+
   gtk_container_add (GTK_CONTAINER (switcher->priv->notifications_window),
 		     GTK_WIDGET (switcher->priv->menu_notifications));
 
@@ -962,7 +991,7 @@ hd_switcher_menu_constructor (GType gtype,
   g_signal_connect_after (menu_item,
                           "activate",
                           G_CALLBACK (hd_switcher_menu_item_activated),
-                          (gpointer)switcher); 
+                          switcher); 
 
   switcher->priv->notification_groups = 
           g_hash_table_new_full (g_str_hash, 
@@ -1519,7 +1548,7 @@ hd_switcher_menu_create_notifications_menu (HDSwitcherMenu *switcher)
     GHashTable *hints;
     GValue *hint;
     gchar *summary, *body;
-    gboolean ack;
+    gboolean ack, icon_is_set = FALSE;
     gint id;
 
     if (switcher->priv->clear_events_menu_item)
@@ -1594,12 +1623,20 @@ hd_switcher_menu_create_notifications_menu (HDSwitcherMenu *switcher)
 
         hd_switcher_menu_item_set_blinking (HD_SWITCHER_MENU_ITEM (menu_item), !ack);
 
+        g_signal_connect_after (menu_item,
+          	                "activate",
+          		        G_CALLBACK (hd_switcher_menu_item_activated),
+          		        switcher);
+
         hildon_desktop_popup_menu_add_item
          (switcher->priv->menu_notifications, GTK_MENU_ITEM (menu_item));
 
-        if (!ack)
+        if (!ack && !icon_is_set)
+        {
           hd_switcher_menu_replace_blinking_icon (switcher, icon);
-
+          icon_is_set = TRUE;
+	}
+	  
         if (!first_item)
 	  first_item = menu_item;
       }
